-------------------------------------------------------------------------------------------------------
-- Rotacast_XChange - Exporting and Importing Rotacast Data
-------------------------------------------------------------------------------------------------------
-- Modules/Data.lua - Export and Import Data
--
-- Author: Expelliarm5s / November 2020 / All Rights Reserved
--
-- Version 1.0.1
-------------------------------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI

-- luacheck: globals RotacastPerDB GetSpecializationInfo GetSpecialization

local addonName, addon = ...
local Data = addon:NewModule("Data", "AceConsole-3.0")
local AceSerializer = LibStub("AceSerializer-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
-- local private = {}
-------------------------------------------------------------------------------------------------------

------------------------------------------------------------------------------
-- Debug Stuff

function Data:DebugPrintf(...)
	if addon.isDebug then
		local status, res = pcall(format, ...)
		if status then
			addon:DebugLog("Data~" .. res)
		end
	end
end

------------------------------------------------------------------------------
-- Login

function Data:Login()
	Data:DebugPrintf("Login()")
end

function Data:SecTimer()
	-- Item:DebugPrintf("SecTimer()")
end

function Data:Export()
	Data:DebugPrintf("Export()")

	if not RotacastPerDB then
		Data:DebugPrintf(L["Rotacast not loaded!"])
		return "Rotacast not loaded!"
	end

	-- find Spec ID
	local currentSpecID, currentSpecName = GetSpecializationInfo(GetSpecialization())
	local data = { currentSpecID = currentSpecID, currentSpecName = currentSpecName }

	if RotacastPerDB and RotacastPerDB.SpecData and data.currentSpecID and RotacastPerDB.SpecData[data.currentSpecID] then
		data.rota = RotacastPerDB.SpecData[currentSpecID]
	end

	if data.rota then
		addon:Printf(L["Export Rotacast Data for SpecID %s: %s"], tostring(currentSpecID), tostring(currentSpecName))

		-- serialize data
		local dataSerz = AceSerializer:Serialize(data)

		if dataSerz then
			return nil, dataSerz
		else
			return "Cannot export data!"
		end
	else
		return format("Cannot find Rotacast Data for SpecID %s: %s", tostring(currentSpecID), tostring(currentSpecName))
	end
end

function Data:Import(dataSerz)
	Data:DebugPrintf("Import()")

	if not RotacastPerDB then
		Data:DebugPrintf("Rotacast not loaded!")
		return "Rotacast not loaded!"
	end

	local result, data = AceSerializer:Deserialize(dataSerz)
	if not result then
		return "Invalid Data: " .. data
	end

	local currentSpecID, currentSpecName = GetSpecializationInfo(GetSpecialization())

	local currentData
	if RotacastPerDB and RotacastPerDB.SpecData and RotacastPerDB.SpecData[currentSpecID] then
		currentData = RotacastPerDB.SpecData[currentSpecID]
	else
		return "Cannot detect Rotacast data!"
	end

	if currentData then
		if data.currentSpecID and currentSpecID and data.currentSpecID == currentSpecID then
			if data.rota then
				RotacastPerDB.SpecData[currentSpecID] = data.rota

				addon:DebugPrintf("Imported SpecID %s: %s", tostring(data.currentSpecID), tostring(dataSerz))
				addon:Printf("Imported Rotacast Data for SpecID %s: %s successfully!", tostring(currentSpecID), tostring(currentSpecName or ""))
				addon.GUI:SetStatusLine(format("Imported Rotacast Data for SpecID %s: %s successfully!",
					tostring(currentSpecID), tostring(currentSpecName or "")))

				local btnRotaDown = _G["Rotacast.Frames.Edit.SequenceDown"]
				local m = 1
				if tonumber(data.rota.Max) then
					m = data.rota.Max
				end
				if btnRotaDown and btnRotaDown.Click then
					for i = 1, m do
						addon.GUI:DebugPrintf("Click Down: %s!", tostring(i))
						btnRotaDown:Click()
					end
				end
			else
				addon:DebugPrintf("data.rota is nil!")
				return "No Data to Import!"
			end
		else
			return format("Current character spec is %s, but import data spec is %s!",
				tostring(currentSpecName or ""),
				tostring(data.currentSpecName or "undefined"))
		end
	else
		return format("Cannot find Rotacast data for SpecID %s", tostring(currentSpecID))
	end
end

-- EOF
